==> rktSNS_1.070120.tgz: rktSNS/webapp/modules/admin/community/community.php <==
<?php
/* ========================================================================
 - [modules/admin/community/community.php]
 -      コミュニティ情報
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2007/01/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_upload.php';
require_once WEBAPP_LIB_DIR.'wap_admin.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_admin
{
    /**
     * コミュニティID
     * @var integer
     */
    var $id = 0;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN));

        $this->setTemplateFile('admin/community/community.tpl');
        $this->addJavas('common.js');

        // URL引数の取得
        $this->setSafety('id');
        $this->Assign('id', $this->id);

        $this->set_community();
        $this->set_category();
        $this->set_member();
        $this->set_topic();
        $this->set_event();

        /* 削除 */
        if ($this->delete_community()){
            header('Location: '.HTTP_ACTION.'admin/community/result/complete/');
            exit();
        }

        $visibilitys = array(
            VISIBILITY_PUBLIC=>  VISIBILITY_LABEL_PUBLIC_ENTRY,
            VISIBILITY_PRIVATE=> VISIBILITY_LABEL_PRIVATE_ENTRY,
            VISIBILITY_HIDDEN=>  VISIBILITY_LABEL_HIDDEN_ENTRY,
        );
        $this->Assign('visibilitys', $visibilitys);
    }

    /**
     * コミュニティ情報の設定
     *
     * @access private
     * @return void
     */
    function set_community()
    {
        $sql=
            'SELECT '.
                'com.id as id,'.
                'com.community as community,'.
                'com.regist_date as regist_date,'.
                'com.visibility as visibility,'.
                'com.total as total,'.
                'com.publicity as publicity,'.
                'com.ref_account as ref_account,'.
                'pro.nickname as nickname,'.
                'prf.prefecture as prefecture,'.
                'pic.filename as src,'.
                'pic.width as width,'.
                'pic.height as height,'.
                'pic.thumbnail as t_src,'.
                'pic.t_width as t_width,'.
                'pic.t_height as t_height '.
            'FROM '.
                DB_PREFIX.'com_community com '.
                    'LEFT JOIN '.DB_PREFIX.'com_picture pic '.
                    'ON com.id = pic.ref_community AND '.
                       'pic.status = '.STATUS_PICTURE_COMMUNITY.','.
                DB_PREFIX.'act_account act,'.
                DB_PREFIX.'act_profile pro,'.
                DB_PREFIX.'ara_prefecture prf '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.id = com.ref_account AND '.
                'prf.id = com.ref_prefecture AND '.
                'com.id = '.$this->id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        $this->Assign('community',$result);
    }

    /**
     * 会員の設定
     *
     * @access private
     * @return void
     */
    function set_member()
    {
        $sql=
            'SELECT '.
                'act.id as id,'.
                'pro.nickname as nickname,'.
                'act.friend_number as friend_number,'.
                'pht.thumbnail as src,'.
                'pht.t_width as width,'.
                'pht.t_height as height '.
            'FROM '.
                DB_PREFIX.'act_account act '.
                    'LEFT JOIN '.DB_PREFIX.'act_photo pht '.
                    'ON act.id = pht.ref_account AND '.
                        'pht.status = '.STATUS_PHOTO_MAIN.','.
                DB_PREFIX.'act_profile pro,'.
                DB_PREFIX.'com_names nam '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.id = nam.ref_account AND '.
                'nam.ref_community = '.$this->id .' AND '.
                'act.avail = '.AVAIL_ENABLE.' AND '.
                '(nam.status = '.STATUS_COMMUNITY_ADMIN.' OR '.
                 'nam.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
                 'nam.status = '.STATUS_COMMUNITY_CHANGE.') '.
            'ORDER BY '.
                'nam.modify '.
            'LIMIT 9';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $list=array();
        $row=0;
        foreach ($result as $value){
            $value['src'] = empty($value['src'])?NOPHOTO_SMALL:$value['src'];
            $value['width'] = empty($value['width'])?PHOTO_SMALL_SIZE:$value['width'];
            $value['height'] = empty($value['height'])?PHOTO_SMALL_SIZE:$value['height'];

            $list[] = array(
                'id'=>            $value['id'],
                'nickname'=>      $value['nickname'],
                'friend_number'=> $value['friend_number'],
                'src'=>           $value['src'],
                'width'=>         $value['width'],
                'height'=>        $value['height']
            );
            $row++;
        }

        $inits = array (0,2,1);
        for ($row=$inits[$row%3]; $row; $row--){
            $list[] = array(
                'id'=> 0,
                'nickname'=> '',
                'friend_number'=>0,
                'src'=>    '',
                'width'=>  0,
                'height'=> 0
            );
        }
        $this->Assign('member', $this->shape_member($list));
    }

    /**
     * 会員情報の成形
     *
     * @access private
     * @return array
     */
    function shape_member($friends)
    {
        $list = array();
        $row = 0;
        $column = 0;
        foreach ($friends as $value){
            // 改行処理
            if ($column >= 3){
                $column = 0;
                $row++;
            }
            $list[$row][$column] = $value;
            $column++;
        } // foreach ($result as $value)
        
        return $list;
    }

    /**
     * カテゴリの設定
     *
     * @access private
     * @return void
     */
    function set_category()
    {
        $sql = 
            'SELECT '.
                'cat.category as category '.
            'FROM '.
                DB_PREFIX.'com_genre gen,'.
                DB_PREFIX.'com_category cat,'.
                DB_PREFIX.'com_select sel '.
            'WHERE '.
                'gen.id = cat.ref_genre AND '.
                'cat.id = sel.ref_category AND '.
                'sel.ref_community = '.$this->id .' '.
            'ORDER BY '.
                'gen.sort,'.
                'cat.sort';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if (empty($result)){
            return ;
        }

        $this->Assign('categorys', $result);
    }

    /**
     * トピックの設定
     *
     * @access private
     * @return void
     */
    function set_topic()
    {
        $sql=
            'SELECT '.
                'tpc.id as id,'.
                'tpc.modify as modify,'.
                'tpc.topic as topic,'.
                'count(cmt.id) as post '.
            'FROM '.
                DB_PREFIX.'com_topic tpc '.
                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
                    'ON tpc.id = cmt.ref_topic '.
            'WHERE '.
                'tpc.status = '.STATUS_TOPIC_BULLETIN.' AND '.
                'tpc.ref_community = '.$this->id.' '.
            'GROUP BY '.
                'tpc.id '.
            'ORDER BY '.
                'tpc.modify DESC '.
            'LIMIT 5';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->Assign('topics', $result);
    }

    /**
     * イベントの設定
     *
     * @access private
     * @return void
     */
    function set_event()
    {
        $sql=
            'SELECT '.
                'tpc.id as id,'.
                'tpc.modify as modify,'.
                'tpc.topic as event,'.
                'count(cmt.id) as post '.
            'FROM '.
                DB_PREFIX.'com_topic tpc '.
                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
                    'ON tpc.id = cmt.ref_topic '.
            'WHERE '.
                'tpc.status = '.STATUS_TOPIC_EVENT.' AND '.
                'tpc.ref_community = '.$this->id.' '.
            'GROUP BY '.
                'tpc.id '.
            'ORDER BY '.
                'tpc.modify DESC '.
            'LIMIT 5';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->Assign('events', $result);
    }

    /**
     * コミュニティの削除
     *
     * @access private
     * @return integer  データ操作結果
     */
    function delete_community()
    {
        if (empty($_POST['delete'])){
            return false;
        }
        /* 画像の削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* 名簿の削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_names '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* コメントの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_comment '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* イベント参加の削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_entry '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* トピックの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_topic '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* 選択カテゴリの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_select '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* コミュニティの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_community '.
            'WHERE '.
                'id = '.$this->id;
        $this->objdb->exec($sql);

        /* 関連画像実体の削除 */
        $objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM);
        $objfile->delete(array('gid'=>$this->id));
        
        /* ポータル用トピック・イベントデータの削除 */
        $this->request_delete();
        
        return true;
    }

    /****************************************************************/
    /**********    ポータルへのリクエスト処理     *******************/
    /****************************************************************/
    /**
     * ポータル用トピック・イベントデータの削除
     *
     * @access private
     * @return boolean
     */
    function request_delete()
    {
        include_once LIB_DIR.'PEAR/HTTP/Request.php';

        $req =& new HTTP_Request(WAP_HTTP_REQUEST_URL.'exec/public/edit/delete_community/');
        $req->setMethod(HTTP_REQUEST_METHOD_POST);

        $req->addPostData('ref_sns', SNS_ID);
        $req->addPostData('community_id', $this->id);

        $req->addPostData('delete', '1');

        if (!PEAR::isError($req->sendRequest())) {
             $response = $req->getResponseBody();
        } else {
             $response = "error";
        }

        $result = false;
        if (preg_match("/<error>0<\/error>/i", $response)){
            $result = true;
        }

        return $result;
    }
} // webapp
?>

==> rktSNS_1.070510.tgz: rktSNS/webapp/modules/admin/community/community.php <==
<?php
/* ========================================================================
 - [modules/admin/community/community.php]
 -      コミュニティ情報
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
 -      [2007/01/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_upload.php';
require_once WEBAPP_LIB_DIR.'sql_query.php';
require_once WEBAPP_LIB_DIR.'wap_admin.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_admin
{
    /**
     * コミュニティID
     * @var integer
     */
    var $id = 0;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN));

        $this->setTemplateFile('admin/community/community.tpl');
        $this->addJavas('common.js');

        // URL引数の取得
        $this->setSafety('id');
        $this->Assign('id', $this->id);

        $this->set_community();
        $this->set_category();
        $this->set_member();
        $this->set_topic();
        $this->set_event();

        /* 削除 */
        if ($this->delete_community()){
            header('Location: '.HTTP_ACTION.'admin/community/result/complete/');
            exit();
        }

        $visibilitys = array(
            VISIBILITY_PUBLIC=>  VISIBILITY_LABEL_PUBLIC_ENTRY,
            VISIBILITY_PRIVATE=> VISIBILITY_LABEL_PRIVATE_ENTRY,
            VISIBILITY_HIDDEN=>  VISIBILITY_LABEL_HIDDEN_ENTRY,
        );
        $this->Assign('visibilitys', $visibilitys);
    }

    /**
     * コミュニティ情報の設定
     *
     * @access private
     * @return void
     */
    function set_community()
    {
        $sql=
            'SELECT '.
                'com.id as id,'.
                'com.community as community,'.
                'com.regist_date as regist_date,'.
                'com.visibility as visibility,'.
                'com.total as total,'.
                'com.publicity as publicity,'.
                'com.ref_account as ref_account,'.
                'pro.nickname as nickname,'.
                'prf.prefecture as prefecture,'.
                'pic.filename as src,'.
                'pic.width as width,'.
                'pic.height as height,'.
                'pic.thumbnail as t_src,'.
                'pic.t_width as t_width,'.
                'pic.t_height as t_height '.
            'FROM '.
                DB_PREFIX.'com_community com '.
                    'LEFT JOIN '.DB_PREFIX.'com_picture pic '.
                    'ON com.id = pic.ref_community AND '.
                       'pic.status = '.STATUS_PICTURE_COMMUNITY.','.
                DB_PREFIX.'act_account act,'.
                DB_PREFIX.'act_profile pro,'.
                DB_PREFIX.'ara_prefecture prf '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.id = com.ref_account AND '.
                'prf.id = com.ref_prefecture AND '.
                'com.id = '.$this->id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        $this->Assign('community',$result);
    }

    /**
     * 会員の設定
     *
     * @access private
     * @return void
     */
    function set_member()
    {
        $sql=
            'SELECT '.
                'act.id as id,'.
                'pro.nickname as nickname,'.
                'act.friend_number as friend_number,'.
                'pht.thumbnail as src,'.
                'pht.t_width as width,'.
                'pht.t_height as height '.
            'FROM '.
                DB_PREFIX.'act_account act '.
                    'LEFT JOIN '.DB_PREFIX.'act_photo pht '.
                    'ON act.id = pht.ref_account AND '.
                        'pht.status = '.STATUS_PHOTO_MAIN.','.
                DB_PREFIX.'act_profile pro,'.
                DB_PREFIX.'com_names nam '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.id = nam.ref_account AND '.
                'nam.ref_community = '.$this->id .' AND '.
                'act.avail = '.AVAIL_ENABLE.' AND '.
                sql_query::bitFlag('nam.status & '.STATUS_COMMUNITY_MEMBERS).' '.
            'ORDER BY '.
                'nam.modify '.
            'LIMIT 9';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $list=array();
        $row=0;
        foreach ($result as $value){
            $value['src'] = empty($value['src'])?NOPHOTO_SMALL:$value['src'];
            $value['width'] = empty($value['width'])?PHOTO_SMALL_SIZE:$value['width'];
            $value['height'] = empty($value['height'])?PHOTO_SMALL_SIZE:$value['height'];

            $list[] = array(
                'id'=>            $value['id'],
                'nickname'=>      $value['nickname'],
                'friend_number'=> $value['friend_number'],
                'src'=>           $value['src'],
                'width'=>         $value['width'],
                'height'=>        $value['height']
            );
            $row++;
        }

        $inits = array (0,2,1);
        for ($row=$inits[$row%3]; $row; $row--){
            $list[] = array(
                'id'=> 0,
                'nickname'=> '',
                'friend_number'=>0,
                'src'=>    '',
                'width'=>  0,
                'height'=> 0
            );
        }
        $this->Assign('member', $this->shape_member($list));
    }

    /**
     * 会員情報の成形
     *
     * @access private
     * @return array
     */
    function shape_member($friends)
    {
        $list = array();
        $row = 0;
        $column = 0;
        foreach ($friends as $value){
            // 改行処理
            if ($column >= 3){
                $column = 0;
                $row++;
            }
            $list[$row][$column] = $value;
            $column++;
        } // foreach ($result as $value)
        
        return $list;
    }

    /**
     * カテゴリの設定
     *
     * @access private
     * @return void
     */
    function set_category()
    {
        $sql = 
            'SELECT '.
                'cat.category as category '.
            'FROM '.
                DB_PREFIX.'com_genre gen,'.
                DB_PREFIX.'com_category cat,'.
                DB_PREFIX.'com_select sel '.
            'WHERE '.
                'gen.id = cat.ref_genre AND '.
                'cat.id = sel.ref_category AND '.
                'sel.ref_community = '.$this->id .' '.
            'ORDER BY '.
                'gen.sort,'.
                'cat.sort';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if (empty($result)){
            return ;
        }

        $this->Assign('categorys', $result);
    }

    /**
     * トピックの設定
     *
     * @access private
     * @return void
     */
    function set_topic()
    {
        $sql=
            'SELECT '.
                'tpc.id as id,'.
                'tpc.modify as modify,'.
                'tpc.topic as topic,'.
                'count(cmt.id) as post '.
            'FROM '.
                DB_PREFIX.'com_topic tpc '.
                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
                    'ON tpc.id = cmt.ref_topic '.
            'WHERE '.
                'tpc.status = '.STATUS_TOPIC_BULLETIN.' AND '.
                'tpc.ref_community = '.$this->id.' '.
            'GROUP BY '.
                'tpc.id '.
            'ORDER BY '.
                'tpc.modify DESC '.
            'LIMIT 5';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->Assign('topics', $result);
    }

    /**
     * イベントの設定
     *
     * @access private
     * @return void
     */
    function set_event()
    {
        $sql=
            'SELECT '.
                'tpc.id as id,'.
                'tpc.modify as modify,'.
                'tpc.topic as event,'.
                'count(cmt.id) as post '.
            'FROM '.
                DB_PREFIX.'com_topic tpc '.
                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
                    'ON tpc.id = cmt.ref_topic '.
            'WHERE '.
                'tpc.status = '.STATUS_TOPIC_EVENT.' AND '.
                'tpc.ref_community = '.$this->id.' '.
            'GROUP BY '.
                'tpc.id '.
            'ORDER BY '.
                'tpc.modify DESC '.
            'LIMIT 5';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->Assign('events', $result);
    }

    /**
     * コミュニティの削除
     *
     * @access private
     * @return integer  データ操作結果
     */
    function delete_community()
    {
        if (empty($_POST['delete'])){
            return false;
        }
        /* 画像の削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_picture '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* 名簿の削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_names '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* コメントの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_comment '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* イベント参加の削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_entry '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* トピックの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_topic '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* 選択カテゴリの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_select '.
            'WHERE '.
                'ref_community = '.$this->id;
        $this->objdb->exec($sql);

        /* コミュニティの削除 */
        $sql =
            'DELETE FROM '.
                DB_PREFIX.'com_community '.
            'WHERE '.
                'id = '.$this->id;
        $this->objdb->exec($sql);

        /* 関連画像実体の削除 */
        $objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM);
        $objfile->delete(array('gid'=>$this->id));
        
        /* ポータル用トピック・イベントデータの削除 */
        $this->request_delete();
        
        return true;
    }

    /****************************************************************/
    /**********    ポータルへのリクエスト処理     *******************/
    /****************************************************************/
    /**
     * ポータル用トピック・イベントデータの削除
     *
     * @access private
     * @return boolean
     */
    function request_delete()
    {
        include_once LIB_DIR.'PEAR/HTTP/Request.php';

        $req =& new HTTP_Request(WAP_HTTP_REQUEST_URL.'exec/public/edit/delete_community/');
        $req->setMethod(HTTP_REQUEST_METHOD_POST);

        $req->addPostData('ref_sns', SNS_ID);
        $req->addPostData('community_id', $this->id);

        $req->addPostData('delete', '1');

        if (!PEAR::isError($req->sendRequest())) {
             $response = $req->getResponseBody();
        } else {
             $response = "error";
        }

        $result = false;
        if (preg_match("/<error>0<\/error>/i", $response)){
            $result = true;
        }

        return $result;
    }
} // webapp
?>
